#[repr(C)]pub struct VulkanInfo {
pub memory_idx: u32,
pub device_id: DeviceId,
}Expand description
Memory index and physical device id of the associated VkDeviceMemory.
Fields
memory_idx: u32device_id: DeviceIdTrait Implementations
Sourceimpl Clone for VulkanInfo
impl Clone for VulkanInfo
Sourcefn clone(&self) -> VulkanInfo
fn clone(&self) -> VulkanInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VulkanInfo
impl Debug for VulkanInfo
Sourceimpl Default for VulkanInfo
impl Default for VulkanInfo
Sourcefn default() -> VulkanInfo
fn default() -> VulkanInfo
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VulkanInfo
impl<'de> Deserialize<'de> for VulkanInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromBytes for VulkanInfo
impl FromBytes for VulkanInfo
Sourceimpl FromZeros for VulkanInfo
impl FromZeros for VulkanInfo
Sourcefn new_zeroed() -> Selfwhere
Self: Sized,
fn new_zeroed() -> Selfwhere
Self: Sized,
Creates an instance of
Self from zeroed bytes. Read moreSourcefn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
fn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
Creates a
Box<Self> from zeroed bytes. Read moreSourcefn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
fn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
Creates a
Vec<Self> from zeroed bytes. Read moreSourcefn extend_vec_zeroed(
v: &mut Vec<Self>,
additional: usize,
) -> Result<(), AllocError>where
Self: Sized,
fn extend_vec_zeroed(
v: &mut Vec<Self>,
additional: usize,
) -> Result<(), AllocError>where
Self: Sized,
Extends a
Vec<Self> by pushing additional new items onto the end of
the vector. The new items are initialized with zeros. Read moreSourceimpl Hash for VulkanInfo
impl Hash for VulkanInfo
Sourceimpl IntoBytes for VulkanInfo
impl IntoBytes for VulkanInfo
Sourcefn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
fn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
Gets the bytes of this value mutably. Read more
Sourcefn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
fn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
Sourceimpl Ord for VulkanInfo
impl Ord for VulkanInfo
Sourcefn cmp(&self, other: &VulkanInfo) -> Ordering
fn cmp(&self, other: &VulkanInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VulkanInfo
impl PartialEq for VulkanInfo
Sourcefn eq(&self, other: &VulkanInfo) -> bool
fn eq(&self, other: &VulkanInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VulkanInfo
impl PartialOrd for VulkanInfo
Sourceimpl Serialize for VulkanInfo
impl Serialize for VulkanInfo
Sourceimpl TryFromBytes for VulkanInfo
impl TryFromBytes for VulkanInfo
Sourcefn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
Sourcefn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
Sourcefn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
impl Copy for VulkanInfo
impl Eq for VulkanInfo
impl Immutable for VulkanInfo
impl StructuralPartialEq for VulkanInfo